=======
Storage
=======

This section describes configuration of the different storage backends
supported by kolla.

.. toctree::
   :maxdepth: 1

   ceph-guide
   external-ceph-guide
   cinder-guide
   cinder-guide-hnas
   cinder-guide-quobyte
   manila-guide
   manila-hnas-guide
   swift-guide
